import { Injectable } from '@nestjs/common'
import { ConfigService } from '@nestjs/config'
import * as fs from 'fs/promises'
import * as path from 'path'

import encrypt from 'src/utils/encrypt'

@Injectable()
export class HubService {
  constructor (private readonly configService: ConfigService) { }

  async findHitphoneDesktopServerConfig () {
    try {
      const ENCRYPTION_KEY = this.configService.get<string>('ENCRYPTION_KEY')

      const origin = this.configService.get<string>('HITPHONE_DESKTOP_SERVER_ORIGINS')
      const certificatePem = await fs.readFile(path.join(__dirname, '../../cert-hitphone.pem'), 'utf8')
      const certificateKey = await fs.readFile(path.join(__dirname, '../../cert-hitphone.key'), 'utf8')

      if (!origin || !certificatePem || !certificateKey || !ENCRYPTION_KEY) {
        throw new Error("ENCRYPTION_KEY, HITPHONE_DESKTOP_SERVER_ORIGINS, cert-hitphone.pem or cert-hitphone.key doesn't exist")
      }

      const originSplit = origin.split(',')

      // return keys
      const encryptedOriginReturnKey = encrypt('origin', ENCRYPTION_KEY)
      const encryptedCertificateKeyReturnKey = encrypt('certificateKey', ENCRYPTION_KEY)
      const encryptedCertificatePemReturnKey = encrypt('certificatePem', ENCRYPTION_KEY)

      // return values
      const originEncrypted = originSplit.map((origin) => {
        return encrypt(origin, ENCRYPTION_KEY)
      })
      const encryptedCertificateKey = encrypt(certificateKey, ENCRYPTION_KEY)
      const encryptedCertificatePem = encrypt(certificatePem, ENCRYPTION_KEY)

      return {
        [encryptedOriginReturnKey]: originEncrypted,
        [encryptedCertificateKeyReturnKey]: encryptedCertificateKey,
        [encryptedCertificatePemReturnKey]: encryptedCertificatePem
      }
    } catch (error) {
      throw new Error('Error reading certificate or key file: ' + error.message)
    }
  }
}
