import { Injectable, NestMiddleware } from '@nestjs/common'
import * as morgan from 'morgan'
import { IncomingMessage, ServerResponse } from 'http'

@Injectable()
export class LoggerMiddleware implements NestMiddleware {
  private readonly morganMiddleware: any

  constructor () {
    // Define os tokens personalizados
    morgan.token('timestamp', () => {
      const date = new Date()
      return date.toLocaleString('pt-BR', {
        hour: '2-digit',
        minute: '2-digit',
        second: '2-digit',
        day: '2-digit',
        month: '2-digit',
        year: 'numeric',
        hour12: false
      })
    })

    morgan.token('statusColor', (req: IncomingMessage, res: ServerResponse) => {
      const status = res.headersSent ? res.statusCode : undefined
      const color = status !== undefined
        ? (
            status >= 500
              ? 31
              : status >= 400
                ? 33
                : status >= 300
                  ? 36
                  : status >= 200
                    ? 32
                    : 0
          )
        : 0

      return `\x1b[${color}m${status}\x1b[0m`
    })

    this.morganMiddleware = morgan(':timestamp - :method :url :statusColor :response-time ms - :res[content-length]')
  }

  use (req: IncomingMessage, res: ServerResponse, next: () => void) {
    this.morganMiddleware(req, res, next)
  }
}
