import { Controller, Get, Post, Body, Patch, Param, Delete, InternalServerErrorException, Logger } from '@nestjs/common'
import { SmsService } from './sms.service'
import { CreateSmDto } from './dto/create-sm.dto'
import { UpdateSmDto } from './dto/update-sm.dto'

@Controller('sms')
export class SmsController {
  constructor (private readonly smsService: SmsService) {}

  @Post('/:provider')
  createSmsMessage (@Body() smsMessage: CreateSmDto) {
    try {
      const hitphoneDesktopServerConfig = await this.hubService.findHitphoneDesktopServerConfig()
      return {
        ...hitphoneDesktopServerConfig
      }
    } catch (error) {
      Logger.error(`Error reading certificate or key file: ${error.message}`)
      throw new InternalServerErrorException({
        message: 'Error reading config informations'
      })
    }
    // return this.smsService.create(createSmDto)
  }

  @Get()
  findAll () {
    return this.smsService.findAll()
  }

  @Get(':id')
  findOne (@Param('id') id: string) {
    return this.smsService.findOne(+id)
  }

  @Patch(':id')
  update (@Param('id') id: string, @Body() updateSmDto: UpdateSmDto) {
    return this.smsService.update(+id, updateSmDto)
  }

  @Delete(':id')
  remove (@Param('id') id: string) {
    return this.smsService.remove(+id)
  }
}
